@@ -1,4 +1,4 @@
 from .channel_chi import ChiFinder
 
 
-__all__ = ['ChiFinder', ]
+__all__ = ["ChiFinder"]
