@@ -86,12 +86,12 @@ array([ 0. ,  0. ,  0. ,  0. ,
         0. ,  1.1,  1.1,  1.1,  0. ,
         0. ,  0. ,  0. ,  0. ])
 """
-from landlab import Component, FieldError
 import numpy as np
+
+from landlab import Component, FieldError
 from landlab.grid.structured_quad import links
 from landlab.utils.decorators import use_file_name_or_kwds
 
-
 _SEVEN_OVER_THREE = 7.0 / 3.0
 
 
@@ -111,10 +111,10 @@ class OverlandFlow(Component):
     The primary method of this class is :func:`run_one_step`.
     """
 
-    _name = 'OverlandFlow'
+    _name = "OverlandFlow"
 
     _cite_as = """@article{adams2017landlab,
-	title={The Landlab v1. 0 OverlandFlow component: a Python
+        title={The Landlab v1. 0 OverlandFlow component: a Python
             tool for computing shallow-water flow across watersheds},
         author={Adams, Jordan M and Gasparini, Nicole M and
             Hobley, Daniel EJ and Tucker, Gregory E and
@@ -129,42 +129,49 @@ class OverlandFlow(Component):
         }
     """
 
-    _input_var_names = (
-        'surface_water__depth',
-        'topographic__elevation',
-    )
+    _input_var_names = ("surface_water__depth", "topographic__elevation")
 
     _output_var_names = (
-        'surface_water__depth',
-        'surface_water__discharge',
-        'water_surface__gradient',
+        "surface_water__depth",
+        "surface_water__discharge",
+        "water_surface__gradient",
     )
 
     _var_units = {
-        'surface_water__depth': 'm',
-        'surface_water__discharge': 'm3/s',
-        'topographic__elevation': 'm',
-        'water_surface__gradient': '-',
+        "surface_water__depth": "m",
+        "surface_water__discharge": "m3/s",
+        "topographic__elevation": "m",
+        "water_surface__gradient": "-",
     }
 
     _var_mapping = {
-        'surface_water__depth': 'node',
-        'topographic__elevtation': 'node',
-        'surface_water__discharge': 'link',
-        'water_surface__gradient': 'link',
+        "surface_water__depth": "node",
+        "topographic__elevtation": "node",
+        "surface_water__discharge": "link",
+        "water_surface__gradient": "link",
     }
 
     _var_doc = {
-        'surface_water__depth': 'The depth of water at each node.',
-        'topographic__elevtation': 'The land surface elevation.',
-        'surface_water__discharge': 'The discharge of water on active links.',
-        'water_surface__gradient': 'Downstream gradient of the water surface.',
+        "surface_water__depth": "The depth of water at each node.",
+        "topographic__elevtation": "The land surface elevation.",
+        "surface_water__discharge": "The discharge of water on active links.",
+        "water_surface__gradient": "Downstream gradient of the water surface.",
     }
 
     @use_file_name_or_kwds
-    def __init__(self, grid, default_fixed_links=False, h_init=0.00001,
-                 alpha=0.7, mannings_n=0.03, g=9.81, theta=0.8,
-                 rainfall_intensity=0.0, steep_slopes=False, **kwds):
+    def __init__(
+        self,
+        grid,
+        default_fixed_links=False,
+        h_init=0.00001,
+        alpha=0.7,
+        mannings_n=0.03,
+        g=9.81,
+        theta=0.8,
+        rainfall_intensity=0.0,
+        steep_slopes=False,
+        **kwds
+    ):
         """Create an overland flow component.
 
         Parameters
@@ -193,7 +200,7 @@ class OverlandFlow(Component):
 
         self.h_init = h_init
         self.alpha = alpha
-        
+
         if type(mannings_n) is str:
             self.mannings_n = self.grid.at_link[mannings_n]
         else:
@@ -204,44 +211,53 @@ class OverlandFlow(Component):
         self.rainfall_intensity = rainfall_intensity
         self.steep_slopes = steep_slopes
 
-
         # Now setting up fields at the links...
         # For water discharge
         try:
-            self.q = grid.add_zeros('surface_water__discharge', at='link',
-                units=self._var_units['surface_water__discharge'])
+            self.q = grid.add_zeros(
+                "surface_water__discharge",
+                at="link",
+                units=self._var_units["surface_water__discharge"],
+            )
 
         except FieldError:
             # Field was already set; still, fill it with zeros
-            self.q = grid.at_link['surface_water__discharge']
+            self.q = grid.at_link["surface_water__discharge"]
             self.q.fill(0.)
 
         # For water depths calculated at links
         try:
-            self.h_links = grid.add_zeros('surface_water__depth', at='link',
-                                          units=self._var_units[
-                                              'surface_water__depth'])
+            self.h_links = grid.add_zeros(
+                "surface_water__depth",
+                at="link",
+                units=self._var_units["surface_water__depth"],
+            )
         except FieldError:
-            self.h_links = grid.at_link['surface_water__depth']
+            self.h_links = grid.at_link["surface_water__depth"]
             self.h_links.fill(0.)
 
         self.h_links += self.h_init
 
         try:
-            self.h = grid.add_zeros('surface_water__depth', at='node',
-                units=self._var_units['surface_water__depth'])
+            self.h = grid.add_zeros(
+                "surface_water__depth",
+                at="node",
+                units=self._var_units["surface_water__depth"],
+            )
 
         except FieldError:
             # Field was already set
-            self.h = grid.at_node['surface_water__depth']
+            self.h = grid.at_node["surface_water__depth"]
 
         self.h += self.h_init
 
         # For water surface slopes at links
         try:
-            self.water_surface_slope = grid.add_zeros('water_surface__gradient', at='link')
+            self.water_surface_slope = grid.add_zeros(
+                "water_surface__gradient", at="link"
+            )
         except FieldError:
-            self.water_surface_slope = grid.at_link['water_surface__gradient']
+            self.water_surface_slope = grid.at_link["water_surface__gradient"]
             self.water_surface_slope.fill(0.)
 
         # Start time of simulation is at 1.0 s
@@ -265,7 +281,7 @@ class OverlandFlow(Component):
         self.default_fixed_links = default_fixed_links
 
         # Assiging a class variable to the elevation field.
-        self.z = self._grid.at_node['topographic__elevation']
+        self.z = self._grid.at_node["topographic__elevation"]
 
     def calc_time_step(self):
         """Calculate time step.
@@ -273,8 +289,11 @@ class OverlandFlow(Component):
         Adaptive time stepper from Bates et al., 2010 and de Almeida
         et al., 2012
         """
-        self.dt = (self.alpha * self._grid.dx / np.sqrt(self.g * np.amax(
-            self._grid.at_node['surface_water__depth'])))
+        self.dt = (
+            self.alpha
+            * self._grid.dx
+            / np.sqrt(self.g * np.amax(self._grid.at_node["surface_water__depth"]))
+        )
 
         return self.dt
 
@@ -285,15 +304,18 @@ class OverlandFlow(Component):
         needed for the de Almeida solution.
         """
         # First we identify all active links
-        
-        self.active_ids = links.active_link_ids(self.grid.shape,
-                                                self.grid.status_at_node)
 
-        self.active_links_at_open_bdy =self.grid._active_links_at_node(
-                                    self.grid.open_boundary_nodes).transpose()
-        
+        self.active_ids = links.active_link_ids(
+            self.grid.shape, self.grid.status_at_node
+        )
+
+        self.active_links_at_open_bdy = self.grid._active_links_at_node(
+            self.grid.open_boundary_nodes
+        ).transpose()
+
         self.active_links_at_open_bdy = self.active_links_at_open_bdy[
-                                np.where(self.active_links_at_open_bdy > -1)]
+            np.where(self.active_links_at_open_bdy > -1)
+        ]
 
         # And then find all horizontal link IDs (Active and Inactive)
         self.horizontal_ids = links.horizontal_link_ids(self.grid.shape)
@@ -303,7 +325,8 @@ class OverlandFlow(Component):
 
         # Find all horizontal active link ids
         self.horizontal_active_link_ids = links.horizontal_active_link_ids(
-            self.grid.shape, self.active_ids)
+            self.grid.shape, self.active_ids
+        )
 
         # Now we repeat this process for the vertical links.
         # First find the vertical link ids and reshape it into a 1-D array
@@ -311,72 +334,79 @@ class OverlandFlow(Component):
 
         # Find the *active* verical link ids
         self.vertical_active_link_ids = links.vertical_active_link_ids(
-            self.grid.shape, self.active_ids)
+            self.grid.shape, self.active_ids
+        )
 
         if self.default_fixed_links is True:
             fixed_link_ids = links.fixed_link_ids(
-                self.grid.shape, self.grid.status_at_node)
+                self.grid.shape, self.grid.status_at_node
+            )
             fixed_horizontal_links = links.horizontal_fixed_link_ids(
-                self.grid.shape, fixed_link_ids)
+                self.grid.shape, fixed_link_ids
+            )
             fixed_vertical_links = links.vertical_fixed_link_ids(
-                self.grid.shape, fixed_link_ids)
+                self.grid.shape, fixed_link_ids
+            )
             self.horizontal_active_link_ids = np.maximum(
-                self.horizontal_active_link_ids, fixed_horizontal_links)
+                self.horizontal_active_link_ids, fixed_horizontal_links
+            )
             self.vertical_active_link_ids = np.maximum(
-                self.vertical_active_link_ids, fixed_vertical_links)
-            self.active_neighbors = find_active_neighbors_for_fixed_links(
-                self.grid)
-            
+                self.vertical_active_link_ids, fixed_vertical_links
+            )
+            self.active_neighbors = find_active_neighbors_for_fixed_links(self.grid)
+
         self.vert_bdy_ids = self.active_links_at_open_bdy[
-                            links.is_vertical_link(self.grid.shape, 
-                                            self.active_links_at_open_bdy)]
-                                                   
-        self.vert_bdy_ids = links.nth_vertical_link(self.grid.shape, 
-                                                    self.vert_bdy_ids)
-        
+            links.is_vertical_link(self.grid.shape, self.active_links_at_open_bdy)
+        ]
+
+        self.vert_bdy_ids = links.nth_vertical_link(self.grid.shape, self.vert_bdy_ids)
+
         self.horiz_bdy_ids = self.active_links_at_open_bdy[
-                            links.is_horizontal_link(self.grid.shape, 
-                                            self.active_links_at_open_bdy)]
-                                                     
-        self.horiz_bdy_ids = links.nth_horizontal_link(self.grid.shape,
-                                                  self.horiz_bdy_ids)
-        
+            links.is_horizontal_link(self.grid.shape, self.active_links_at_open_bdy)
+        ]
+
+        self.horiz_bdy_ids = links.nth_horizontal_link(
+            self.grid.shape, self.horiz_bdy_ids
+        )
+
         # Using the active vertical link ids we can find the north
         # and south vertical neighbors
         self.north_neighbors = links.vertical_north_link_neighbor(
-            self.grid.shape, self.vertical_active_link_ids)
+            self.grid.shape, self.vertical_active_link_ids
+        )
         self.south_neighbors = links.vertical_south_link_neighbor(
-            self.grid.shape, self.vertical_active_link_ids)
+            self.grid.shape, self.vertical_active_link_ids
+        )
 
         # Using the horizontal active link ids, we can find the west and
         # east neighbors
         self.west_neighbors = links.horizontal_west_link_neighbor(
-            self.grid.shape, self.horizontal_active_link_ids)
+            self.grid.shape, self.horizontal_active_link_ids
+        )
         self.east_neighbors = links.horizontal_east_link_neighbor(
-            self.grid.shape, self.horizontal_active_link_ids)
+            self.grid.shape, self.horizontal_active_link_ids
+        )
 
-        ## replace bdy condition links
-        (ids, ) = np.where(self.west_neighbors[self.horiz_bdy_ids] == -1)
+        # replace bdy condition links
+        (ids,) = np.where(self.west_neighbors[self.horiz_bdy_ids] == -1)
         ids = self.horiz_bdy_ids[ids]
         self.west_neighbors[ids] = self.horizontal_active_link_ids[ids]
-        
-        (ids, ) = np.where(self.east_neighbors[self.horiz_bdy_ids] == -1)
+
+        (ids,) = np.where(self.east_neighbors[self.horiz_bdy_ids] == -1)
         ids = self.horiz_bdy_ids[ids]
         self.east_neighbors[ids] = self.horizontal_active_link_ids[ids]
 
-        (ids, ) = np.where(self.north_neighbors[self.vert_bdy_ids] == -1)
+        (ids,) = np.where(self.north_neighbors[self.vert_bdy_ids] == -1)
         ids = self.vert_bdy_ids[ids]
         self.north_neighbors[ids] = self.vertical_active_link_ids[ids]
-        
-        (ids, ) = np.where(self.south_neighbors[self.vert_bdy_ids] == -1)
+
+        (ids,) = np.where(self.south_neighbors[self.vert_bdy_ids] == -1)
         ids = self.vert_bdy_ids[ids]
         self.south_neighbors[ids] = self.vertical_active_link_ids[ids]
-        
+
         # Set up arrays for discharge in the horizontal & vertical directions.
-        self.q_horizontal = np.zeros(links.number_of_horizontal_links(
-            self.grid.shape))
-        self.q_vertical = np.zeros(links.number_of_vertical_links(
-            self.grid.shape))
+        self.q_horizontal = np.zeros(links.number_of_horizontal_links(self.grid.shape))
+        self.q_vertical = np.zeros(links.number_of_vertical_links(self.grid.shape))
 
         # Once the neighbor arrays are set up, we change the flag to True!
         self.neighbor_flag = True
@@ -414,11 +444,11 @@ class OverlandFlow(Component):
             # In case another component has added data to the fields, we just
             # reset our water depths, topographic elevations and water
             # discharge variables to the fields.
-            self.h = self.grid['node']['surface_water__depth']
-            self.z = self.grid['node']['topographic__elevation']
-            self.q = self.grid['link']['surface_water__discharge']
-            self.h_links = self.grid['link']['surface_water__depth']
-         
+            self.h = self.grid["node"]["surface_water__depth"]
+            self.z = self.grid["node"]["topographic__elevation"]
+            self.q = self.grid["link"]["surface_water__discharge"]
+            self.h_links = self.grid["link"]["surface_water__depth"]
+
             # Here we identify the core nodes and active links for later use.
             self.core_nodes = self.grid.core_nodes
             self.active_links = self.grid.active_links
@@ -429,8 +459,7 @@ class OverlandFlow(Component):
             zmax = self._grid.map_max_of_link_nodes_to_link(self.z)
             w = self.h + self.z
             wmax = self._grid.map_max_of_link_nodes_to_link(w)
-            hflow = wmax[self._grid.active_links] - zmax[
-                self._grid.active_links]
+            hflow = wmax[self._grid.active_links] - zmax[self._grid.active_links]
 
             # Insert this water depth into an array of water depths at the
             # links.
@@ -438,12 +467,12 @@ class OverlandFlow(Component):
 
             # Now we calculate the slope of the water surface elevation at
             # active links
-            self.water_surface__gradient = (
-                self.grid.calc_grad_at_link(w)[self.grid.active_links])
+            self.water_surface__gradient = self.grid.calc_grad_at_link(w)[
+                self.grid.active_links
+            ]
 
             # And insert these values into an array of all links
-            self.water_surface_slope[self.active_links
-                                      ] = self.water_surface__gradient
+            self.water_surface_slope[self.active_links] = self.water_surface__gradient
             # If the user chooses to set boundary links to the neighbor value,
             # we set the discharge array to have the boundary links set to
             # their neighbor value
@@ -457,48 +486,88 @@ class OverlandFlow(Component):
             # '-1' indices, we will simply insert an value of 0.0 discharge (in
             # units of L^2/T) to the end of the discharge array.
             self.q = np.append(self.q, [0])
-            
+
             horiz = self.horizontal_ids
             vert = self.vertical_ids
             # Now we calculate discharge in the horizontal direction
             try:
-                self.q[horiz] = ((
-                    self.theta * self.q[horiz] + (1. - self.theta) / 2. *
-                    (self.q[self.west_neighbors] + self.q[self.east_neighbors]) -
-                    self.g * self.h_links[horiz] * self.dt *
-                    self.water_surface_slope[horiz]) / (1 + self.g * self.dt 
-                    * self.mannings_n ** 2. * abs(self.q[horiz]) / 
-                    self.h_links[horiz] ** _SEVEN_OVER_THREE))
-    
+                self.q[horiz] = (
+                    self.theta * self.q[horiz]
+                    + (1. - self.theta)
+                    / 2.
+                    * (self.q[self.west_neighbors] + self.q[self.east_neighbors])
+                    - self.g
+                    * self.h_links[horiz]
+                    * self.dt
+                    * self.water_surface_slope[horiz]
+                ) / (
+                    1
+                    + self.g
+                    * self.dt
+                    * self.mannings_n ** 2.
+                    * abs(self.q[horiz])
+                    / self.h_links[horiz] ** _SEVEN_OVER_THREE
+                )
+
                 # ... and in the vertical direction
-                self.q[vert] = ((
-                    self.theta * self.q[vert] + (1 - self.theta) / 2. *
-                    (self.q[self.north_neighbors] + self.q[self.south_neighbors]) -
-                    self.g * self.h_links[vert] * self.dt *
-                    self.water_surface_slope[vert]) / (1 + self.g * self.dt * 
-                    self.mannings_n ** 2. * abs(self.q[vert]) / 
-                    self.h_links[vert] ** _SEVEN_OVER_THREE))
-                
+                self.q[vert] = (
+                    self.theta * self.q[vert]
+                    + (1 - self.theta)
+                    / 2.
+                    * (self.q[self.north_neighbors] + self.q[self.south_neighbors])
+                    - self.g
+                    * self.h_links[vert]
+                    * self.dt
+                    * self.water_surface_slope[vert]
+                ) / (
+                    1
+                    + self.g
+                    * self.dt
+                    * self.mannings_n ** 2.
+                    * abs(self.q[vert])
+                    / self.h_links[vert] ** _SEVEN_OVER_THREE
+                )
+
             except ValueError:
-                self.mannings_n = self.grid['link']['mannings_n']
+                self.mannings_n = self.grid["link"]["mannings_n"]
                 # if manning's n in a field
                 # calc discharge in horizontal
-                self.q[horiz] = ((
-                    self.theta * self.q[horiz] + (1. - self.theta) / 2. *
-                    (self.q[self.west_neighbors] + self.q[self.east_neighbors]) -
-                    self.g * self.h_links[horiz] * self.dt *
-                    self.water_surface_slope[horiz]) / (1 + self.g * self.dt 
-                    * self.mannings_n[horiz]** 2. * abs(self.q[horiz]) / 
-                    self.h_links[horiz] ** _SEVEN_OVER_THREE))
-    
+                self.q[horiz] = (
+                    self.theta * self.q[horiz]
+                    + (1. - self.theta)
+                    / 2.
+                    * (self.q[self.west_neighbors] + self.q[self.east_neighbors])
+                    - self.g
+                    * self.h_links[horiz]
+                    * self.dt
+                    * self.water_surface_slope[horiz]
+                ) / (
+                    1
+                    + self.g
+                    * self.dt
+                    * self.mannings_n[horiz] ** 2.
+                    * abs(self.q[horiz])
+                    / self.h_links[horiz] ** _SEVEN_OVER_THREE
+                )
+
                 # ... and in the vertical direction
-                self.q[vert] = ((
-                    self.theta * self.q[vert] + (1 - self.theta) / 2. *
-                    (self.q[self.north_neighbors] + self.q[self.south_neighbors]) -
-                    self.g * self.h_links[vert] * self.dt *
-                    self.water_surface_slope[self.vertical_ids]) / (1 + self.g 
-                    * self.dt * self.mannings_n[vert] ** 2. * abs(self.q[vert])
-                    / self.h_links[vert] ** _SEVEN_OVER_THREE))
+                self.q[vert] = (
+                    self.theta * self.q[vert]
+                    + (1 - self.theta)
+                    / 2.
+                    * (self.q[self.north_neighbors] + self.q[self.south_neighbors])
+                    - self.g
+                    * self.h_links[vert]
+                    * self.dt
+                    * self.water_surface_slope[self.vertical_ids]
+                ) / (
+                    1
+                    + self.g
+                    * self.dt
+                    * self.mannings_n[vert] ** 2.
+                    * abs(self.q[vert])
+                    / self.h_links[vert] ** _SEVEN_OVER_THREE
+                )
 
             # Now to return the array to its original length (length of number
             # of all links), we delete the extra 0.0 value from the end of the
@@ -517,8 +586,7 @@ class OverlandFlow(Component):
                 # Our two limiting factors, the froude number and courant
                 # number.
                 # Looking a calculated q to be compared to our Fr number.
-                calculated_q = (self.q / self.h_links) / np.sqrt(self.g *
-                                                                 self.h_links)
+                calculated_q = (self.q / self.h_links) / np.sqrt(self.g * self.h_links)
 
                 # Looking at our calculated q and comparing it to Courant no.,
                 q_courant = self.q * self.dt / self.grid.dx
@@ -527,65 +595,67 @@ class OverlandFlow(Component):
                 water_div_4 = self.h_links / 4.
 
                 # IDs where water discharge is positive...
-                (positive_q, ) = np.where(self.q > 0)
+                (positive_q,) = np.where(self.q > 0)
 
                 # ... and negative.
-                (negative_q, ) = np.where(self.q < 0)
+                (negative_q,) = np.where(self.q < 0)
 
                 # Where does our calculated q exceed the Froude number? If q
                 # does exceed the Froude number, we are getting supercritical
                 # flow and discharge needs to be reduced to maintain stability.
-                (Froude_logical, ) = np.where((calculated_q) > Fr)
-                (Froude_abs_logical, ) = np.where(abs(calculated_q) > Fr)
+                (Froude_logical,) = np.where((calculated_q) > Fr)
+                (Froude_abs_logical,) = np.where(abs(calculated_q) > Fr)
 
                 # Where does our calculated q exceed the Courant number and
                 # water depth divided amongst 4 links? If the calculated q
                 # exceeds the Courant number and is greater than the water
                 # depth divided by 4 links, we reduce discharge to maintain
                 # stability.
-                (water_logical, ) = np.where(q_courant > water_div_4)
-                (water_abs_logical, ) = np.where(abs(q_courant) > water_div_4)
+                (water_logical,) = np.where(q_courant > water_div_4)
+                (water_abs_logical,) = np.where(abs(q_courant) > water_div_4)
 
                 # Where are these conditions met? For positive and negative q,
                 # there are specific rules to reduce q. This step finds where
                 # the discharge values are positive or negative and where
                 # discharge exceeds the Froude or Courant number.
-                self.if_statement_1 = np.intersect1d(positive_q,
-                                                     Froude_logical)
-                self.if_statement_2 = np.intersect1d(negative_q,
-                                                     Froude_abs_logical)
+                self.if_statement_1 = np.intersect1d(positive_q, Froude_logical)
+                self.if_statement_2 = np.intersect1d(negative_q, Froude_abs_logical)
                 self.if_statement_3 = np.intersect1d(positive_q, water_logical)
-                self.if_statement_4 = np.intersect1d(negative_q,
-                                                     water_abs_logical)
+                self.if_statement_4 = np.intersect1d(negative_q, water_abs_logical)
 
                 # Rules 1 and 2 reduce discharge by the Froude number.
-                self.q[self.if_statement_1] = (
-                    self.h_links[self.if_statement_1] *
-                    (np.sqrt(self.g * self.h_links[self.if_statement_1]) * Fr))
+                self.q[self.if_statement_1] = self.h_links[self.if_statement_1] * (
+                    np.sqrt(self.g * self.h_links[self.if_statement_1]) * Fr
+                )
 
-                self.q[self.if_statement_2] = (
-                    0. - (self.h_links[self.if_statement_2] *
-                          np.sqrt(self.g * self.h_links[self.if_statement_2]) *
-                          Fr))
+                self.q[self.if_statement_2] = 0. - (
+                    self.h_links[self.if_statement_2]
+                    * np.sqrt(self.g * self.h_links[self.if_statement_2])
+                    * Fr
+                )
 
                 # Rules 3 and 4 reduce discharge by the Courant number.
-                self.q[self.if_statement_3] = (((
-                    self.h_links[self.if_statement_3] * self.grid.dx) / 5.) /
-                    self.dt)
+                self.q[self.if_statement_3] = (
+                    (self.h_links[self.if_statement_3] * self.grid.dx) / 5.
+                ) / self.dt
 
-                self.q[self.if_statement_4] = (0. - (self.h_links[
-                    self.if_statement_4] * self.grid.dx / 5.) / self.dt)
+                self.q[self.if_statement_4] = (
+                    0.
+                    - (self.h_links[self.if_statement_4] * self.grid.dx / 5.) / self.dt
+                )
 
             # Once stability has been restored, we calculate the change in
             # water depths on all core nodes by finding the difference between
             # inputs (rainfall) and the inputs/outputs (flux divergence of
             # discharge)
-            self.dhdt = (self.rainfall_intensity -
-                         self.grid.calc_flux_div_at_node(self.q))
+            self.dhdt = self.rainfall_intensity - self.grid.calc_flux_div_at_node(
+                self.q
+            )
 
             # Updating our water depths...
-            self.h[self.core_nodes] = (self.h[self.core_nodes] +
-                                       self.dhdt[self.core_nodes] * self.dt)
+            self.h[self.core_nodes] = (
+                self.h[self.core_nodes] + self.dhdt[self.core_nodes] * self.dt
+            )
 
             # To prevent divide by zero errors, a minimum threshold water depth
             # must be maintained. To reduce mass imbalances, this is set to
@@ -598,29 +668,29 @@ class OverlandFlow(Component):
 
             # And reset our field values with the newest water depth and
             # discharge.
-            self.grid.at_node['surface_water__depth'] = self.h
-            self.grid.at_link['surface_water__discharge'] = self.q
-#
-#
-#            self.helper_q = self.grid.map_upwind_node_link_max_to_node(self.q)
-#            self.helper_s = self.grid.map_upwind_node_link_max_to_node(
-#                                                    self.water_surface_slope)
-#            
-#            self.helper_q = self.grid.map_max_of_link_nodes_to_link(self.helper_q)
-#            self.helper_s = self.grid.map_max_of_link_nodes_to_link(self.helper_s)
-#
-#            self.grid['link']['surface_water__discharge'][
-#                     self.active_links_at_open_bdy] = self.helper_q[
-#                     self.active_links_at_open_bdy]
-#
-#            self.grid['link']['water_surface__gradient'][
-#                self.active_links_at_open_bdy] = self.helper_s[
-#                self.active_links_at_open_bdy]
-            ## Update nodes near boundary locations - nodes adjacent to
-            ## boundaries may have discharge and water surface slopes
-            ## artifically reduced due to boundary effects. This step removes
-            ## those errors. 
-            
+            self.grid.at_node["surface_water__depth"] = self.h
+            self.grid.at_link["surface_water__discharge"] = self.q
+            #
+            #
+            #            self.helper_q = self.grid.map_upwind_node_link_max_to_node(self.q)
+            #            self.helper_s = self.grid.map_upwind_node_link_max_to_node(
+            #                                                    self.water_surface_slope)
+            #
+            #            self.helper_q = self.grid.map_max_of_link_nodes_to_link(self.helper_q)
+            #            self.helper_s = self.grid.map_max_of_link_nodes_to_link(self.helper_s)
+            #
+            #            self.grid['link']['surface_water__discharge'][
+            #                     self.active_links_at_open_bdy] = self.helper_q[
+            #                     self.active_links_at_open_bdy]
+            #
+            #            self.grid['link']['water_surface__gradient'][
+            #                self.active_links_at_open_bdy] = self.helper_s[
+            #                self.active_links_at_open_bdy]
+            # Update nodes near boundary locations - nodes adjacent to
+            # boundaries may have discharge and water surface slopes
+            # artifically reduced due to boundary effects. This step removes
+            # those errors.
+
             if dt is np.inf:
                 break
             local_elapsed_time += self.dt
@@ -639,7 +709,6 @@ class OverlandFlow(Component):
         """
         self.overland_flow(dt=dt)
 
-
     def discharge_mapper(self, input_discharge, convert_to_volume=False):
         """
         Maps discharge value from links onto nodes.
@@ -664,13 +733,12 @@ class OverlandFlow(Component):
         discharge_vals = np.zeros(self.grid.number_of_links)
         discharge_vals[:] = input_discharge[:]
 
-        if convert_to_volume == True:
+        if convert_to_volume:
             discharge_vals *= self.grid.dx
-        else:
-            pass
 
-        discharge_vals = (discharge_vals[self.grid.links_at_node] *
-                                        self.grid.link_dirs_at_node)
+        discharge_vals = (
+            discharge_vals[self.grid.links_at_node] * self.grid.link_dirs_at_node
+        )
 
         discharge_vals = discharge_vals.flatten()
 
