@@ -2,4 +2,4 @@
 from landlab.components.plant_competition_ca.plant_competition_ca import VegCA
 
 
-__all__ = ['VegCA']
+__all__ = ["VegCA"]
