@@ -2,4 +2,4 @@
 from .vegetation_dynamics import Vegetation
 
 
-__all__ = ['Vegetation', ]
+__all__ = ["Vegetation"]
