@@ -16,12 +16,13 @@ Gradient calculation functions
 """
 
 import numpy as np
-from landlab.utils.decorators import use_field_name_or_array, deprecated
+
 from landlab.core.utils import radians_to_degrees
 from landlab.grid.base import CLOSED_BOUNDARY
+from landlab.utils.decorators import deprecated, use_field_name_or_array
 
 
-@use_field_name_or_array('node')
+@use_field_name_or_array("node")
 def calc_grad_at_link(grid, node_values, out=None):
     """Calculate gradients of node values at links.
 
@@ -65,13 +66,15 @@ def calc_grad_at_link(grid, node_values, out=None):
     LLCATS: LINF GRAD
     """
     if out is None:
-        out = grid.empty(at='link')
-    return np.divide(node_values[grid.node_at_link_head] -
-                     node_values[grid.node_at_link_tail],
-                     grid.length_of_link, out=out)
+        out = grid.empty(at="link")
+    return np.divide(
+        node_values[grid.node_at_link_head] - node_values[grid.node_at_link_tail],
+        grid.length_of_link,
+        out=out,
+    )
 
 
-@deprecated(use='calc_grad_at_link', version='1.0beta')
+@deprecated(use="calc_grad_at_link", version="1.0beta")
 def calc_grad_of_active_link(grid, node_values, out=None):
     """Calculate gradients at active links.
 
@@ -97,8 +100,8 @@ def calc_grad_of_active_link(grid, node_values, out=None):
     return calc_grad_at_active_link(grid, node_values, out)
 
 
-@deprecated(use='calc_grad_at_link', version='1.0beta')
-@use_field_name_or_array('node')
+@deprecated(use="calc_grad_at_link", version="1.0beta")
+@use_field_name_or_array("node")
 def calc_grad_at_active_link(grid, node_values, out=None):
     """Calculate gradients of node values over active links.
 
@@ -125,11 +128,13 @@ def calc_grad_at_active_link(grid, node_values, out=None):
         out = np.empty(len(grid.active_links), dtype=float)
     return np.divide(
         np.diff(node_values[grid.nodes_at_link[grid.active_links]], axis=1).flatten(),
-        grid.length_of_link[grid.active_links], out=out)
+        grid.length_of_link[grid.active_links],
+        out=out,
+    )
 
 
-@deprecated(use='calc_grad_at_link', version='1.0beta')
-@use_field_name_or_array('node')
+@deprecated(use="calc_grad_at_link", version="1.0beta")
+@use_field_name_or_array("node")
 def calculate_gradients_at_faces(grid, node_values, out=None):
     """Calculate gradients of node values over faces.
 
@@ -172,14 +177,17 @@ def calculate_gradients_at_faces(grid, node_values, out=None):
     LLCATS: DEPR GRAD
     """
     if out is None:
-        out = grid.empty(at='face')
+        out = grid.empty(at="face")
     laf = grid.link_at_face
-    return np.divide(node_values[grid.node_at_link_head[laf]] -
-                     node_values[grid.node_at_link_tail[laf]],
-                     grid.length_of_link[laf], out=out)
+    return np.divide(
+        node_values[grid.node_at_link_head[laf]]
+        - node_values[grid.node_at_link_tail[laf]],
+        grid.length_of_link[laf],
+        out=out,
+    )
 
 
-@use_field_name_or_array('node')
+@use_field_name_or_array("node")
 def calc_diff_at_link(grid, node_values, out=None):
     """Calculate differences of node values over links.
 
@@ -213,14 +221,17 @@ def calc_diff_at_link(grid, node_values, out=None):
     LLCATS: LINF GRAD
     """
     if out is None:
-        out = grid.empty(at='link')
+        out = grid.empty(at="link")
     node_values = np.asarray(node_values)
-    return np.subtract(node_values[grid.node_at_link_head],
-                       node_values[grid.node_at_link_tail], out=out)
+    return np.subtract(
+        node_values[grid.node_at_link_head],
+        node_values[grid.node_at_link_tail],
+        out=out,
+    )
 
 
-@deprecated(use='calc_diff_at_link', version='1.0beta')
-@use_field_name_or_array('node')
+@deprecated(use="calc_diff_at_link", version="1.0beta")
+@use_field_name_or_array("node")
 def calculate_diff_at_links(grid, node_values, out=None):
     """Calculate differences of node values over links.
 
@@ -244,8 +255,8 @@ def calculate_diff_at_links(grid, node_values, out=None):
     return calc_diff_at_link(grid, node_values, out)
 
 
-@deprecated(use='calc_diff_at_link', version='1.0beta')
-@use_field_name_or_array('node')
+@deprecated(use="calc_diff_at_link", version="1.0beta")
+@use_field_name_or_array("node")
 def calculate_diff_at_active_links(grid, node_values, out=None):
     """Calculate differences of node values over active links.
 
@@ -275,7 +286,7 @@ def calculate_diff_at_active_links(grid, node_values, out=None):
     return np.subtract(node_values[:, 1], node_values[:, 0], out=out)
 
 
-def calc_unit_normal_at_patch(grid, elevs='topographic__elevation'):
+def calc_unit_normal_at_patch(grid, elevs="topographic__elevation"):
     """Calculate and return the unit normal vector <a, b, c> to a patch.
 
     Parameters
@@ -337,8 +348,9 @@ def calc_unit_normal_at_patch(grid, elevs='topographic__elevation'):
     return nhat / nmag.reshape(grid.number_of_patches, 1)
 
 
-def calc_slope_at_patch(grid, elevs='topographic__elevation',
-                        ignore_closed_nodes=True, unit_normal=None):
+def calc_slope_at_patch(
+    grid, elevs="topographic__elevation", ignore_closed_nodes=True, unit_normal=None
+):
     """Calculate the slope (positive magnitude of gradient) at patches.
 
     If ignore_closed_nodes is True, closed nodes do not affect slope
@@ -392,9 +404,13 @@ def calc_slope_at_patch(grid, elevs='topographic__elevation',
     return slopes_at_patch
 
 
-def calc_grad_at_patch(grid, elevs='topographic__elevation',
-                       ignore_closed_nodes=True,
-                       unit_normal=None, slope_magnitude=None):
+def calc_grad_at_patch(
+    grid,
+    elevs="topographic__elevation",
+    ignore_closed_nodes=True,
+    unit_normal=None,
+    slope_magnitude=None,
+):
     """Calculate the components of the gradient at each patch.
 
     If ignore_closed_nodes is True, closed nodes do not affect gradient
@@ -444,18 +460,23 @@ def calc_grad_at_patch(grid, elevs='topographic__elevation',
         slopes_at_patch = slope_magnitude
     else:
         slopes_at_patch = grid.calc_slope_at_patch(
-            elevs=elevs, ignore_closed_nodes=ignore_closed_nodes,
-            unit_normal=nhat)
-    theta = np.arctan2(- nhat[:, 1], - nhat[:, 0])
+            elevs=elevs, ignore_closed_nodes=ignore_closed_nodes, unit_normal=nhat
+        )
+    theta = np.arctan2(-nhat[:, 1], -nhat[:, 0])
     x_slope_patches = np.cos(theta) * slopes_at_patch
     y_slope_patches = np.sin(theta) * slopes_at_patch
 
     return (x_slope_patches, y_slope_patches)
 
 
-def calc_slope_at_node(grid, elevs='topographic__elevation',
-                       method='patch_mean', ignore_closed_nodes=True,
-                       return_components=False, **kwds):
+def calc_slope_at_node(
+    grid,
+    elevs="topographic__elevation",
+    method="patch_mean",
+    ignore_closed_nodes=True,
+    return_components=False,
+    **kwds
+):
     """Array of slopes at nodes, averaged over neighboring patches.
 
     Produces a value for node slope (i.e., mean gradient magnitude)
@@ -538,45 +559,52 @@ def calc_slope_at_node(grid, elevs='topographic__elevation',
 
     LLCATS: NINF GRAD SURF
     """
-    if method not in ('patch_mean', 'Horn'):
-        raise ValueError('method name not understood')
+    if method not in ("patch_mean", "Horn"):
+        raise ValueError("method name not understood")
 
     if not ignore_closed_nodes:
         patches_at_node = np.ma.masked_where(
-            grid.patches_at_node == -1, grid.patches_at_node, copy=False)
+            grid.patches_at_node == -1, grid.patches_at_node, copy=False
+        )
     else:
-        patches_at_node = np.ma.masked_where(np.logical_not(
-            grid.patches_present_at_node), grid.patches_at_node, copy=False)
+        patches_at_node = np.ma.masked_where(
+            np.logical_not(grid.patches_present_at_node),
+            grid.patches_at_node,
+            copy=False,
+        )
 
     nhat = grid.calc_unit_normal_at_patch(elevs=elevs)
     slopes_at_patch = grid.calc_slope_at_patch(
-        elevs=elevs, ignore_closed_nodes=ignore_closed_nodes, unit_normal=nhat)
+        elevs=elevs, ignore_closed_nodes=ignore_closed_nodes, unit_normal=nhat
+    )
 
     # now CAREFUL - patches_at_node is MASKED
     slopes_at_node_unmasked = slopes_at_patch[patches_at_node]
-    slopes_at_node_masked = np.ma.array(slopes_at_node_unmasked,
-                                        mask=patches_at_node.mask)
+    slopes_at_node_masked = np.ma.array(
+        slopes_at_node_unmasked, mask=patches_at_node.mask
+    )
     slope_mag = np.mean(slopes_at_node_masked, axis=1).data
 
-    if return_components or method == 'Horn':
+    if return_components or method == "Horn":
         (x_slope_patches, y_slope_patches) = grid.calc_grad_at_patch(
-            elevs=elevs, unit_normal=nhat,
+            elevs=elevs,
+            unit_normal=nhat,
             ignore_closed_nodes=ignore_closed_nodes,
-            slope_magnitude=slopes_at_patch)
+            slope_magnitude=slopes_at_patch,
+        )
         x_slope_unmasked = x_slope_patches[patches_at_node]
-        x_slope_masked = np.ma.array(x_slope_unmasked,
-                                     mask=patches_at_node.mask)
+        x_slope_masked = np.ma.array(x_slope_unmasked, mask=patches_at_node.mask)
         x_slope = np.mean(x_slope_masked, axis=1).data
         y_slope_unmasked = y_slope_patches[patches_at_node]
-        y_slope_masked = np.ma.array(y_slope_unmasked,
-                                     mask=patches_at_node.mask)
+        y_slope_masked = np.ma.array(y_slope_unmasked, mask=patches_at_node.mask)
         y_slope = np.mean(y_slope_masked, axis=1).data
         mean_grad_x = x_slope
         mean_grad_y = y_slope
 
-        if method == 'Horn':
-            slope_mag = np.arctan(np.sqrt(np.tan(y_slope_masked) ** 2 +
-                                          np.tan(x_slope_masked) ** 2))
+        if method == "Horn":
+            slope_mag = np.arctan(
+                np.sqrt(np.tan(y_slope_masked) ** 2 + np.tan(x_slope_masked) ** 2)
+            )
             return slope_mag
         else:
             return slope_mag, (mean_grad_x, mean_grad_y)
@@ -585,9 +613,13 @@ def calc_slope_at_node(grid, elevs='topographic__elevation',
         return slope_mag
 
 
-def calc_aspect_at_node(grid, slope_component_tuple=None,
-                        elevs='topographic__elevation', unit='degrees',
-                        ignore_closed_nodes=True):
+def calc_aspect_at_node(
+    grid,
+    slope_component_tuple=None,
+    elevs="topographic__elevation",
+    unit="degrees",
+    ignore_closed_nodes=True,
+):
     """Get array of aspect of a surface.
 
     Calculates at returns the aspect of a surface. Aspect is returned as
@@ -653,9 +685,9 @@ def calc_aspect_at_node(grid, slope_component_tuple=None,
     """
     if slope_component_tuple:
         if not isinstance(slope_component_tuple, (tuple, list)):
-            raise TypeError('slope_component_tuple must be tuple')
+            raise TypeError("slope_component_tuple must be tuple")
         if len(slope_component_tuple) != 2:
-            raise ValueError('slope_component_tuple must be of length 2')
+            raise ValueError("slope_component_tuple must be of length 2")
     else:
         try:
             elev_array = grid.at_node[elevs]
@@ -664,17 +696,17 @@ def calc_aspect_at_node(grid, slope_component_tuple=None,
             elev_array = elevs
 
         _, slope_component_tuple = grid.calc_slope_at_node(
-            elevs=elev_array, ignore_closed_nodes=ignore_closed_nodes,
-            return_components=True)
+            elevs=elev_array,
+            ignore_closed_nodes=ignore_closed_nodes,
+            return_components=True,
+        )
 
-    angle_from_x_ccw = np.arctan2(
-        - slope_component_tuple[1], - slope_component_tuple[0])
+    angle_from_x_ccw = np.arctan2(-slope_component_tuple[1], -slope_component_tuple[0])
 
-    if unit == 'degrees':
+    if unit == "degrees":
         return radians_to_degrees(angle_from_x_ccw)
-    elif unit == 'radians':
-        angle_from_north_cw = (5. * np.pi / 2. -
-                               angle_from_x_ccw) % (2. * np.pi)
+    elif unit == "radians":
+        angle_from_north_cw = (5. * np.pi / 2. - angle_from_x_ccw) % (2. * np.pi)
         return angle_from_north_cw
     else:
         raise TypeError("unit must be 'degrees' or 'radians'")
