@@ -11,11 +11,10 @@ automated fashion. To modify the text seen on the web, edit the files
 import numpy
 import six
 
-from .base import (CLOSED_BOUNDARY, FIXED_VALUE_BOUNDARY, BAD_INDEX_VALUE,
-                   CORE_NODE)
-from ..core.utils import as_id_array
 from landlab.grid.voronoi import VoronoiDelaunayGrid
-from .decorators import return_readonly_id_array
+
+from ..core.utils import as_id_array
+from .base import BAD_INDEX_VALUE, CLOSED_BOUNDARY, CORE_NODE, FIXED_VALUE_BOUNDARY
 
 
 class HexModelGrid(VoronoiDelaunayGrid):
@@ -56,9 +55,16 @@ class HexModelGrid(VoronoiDelaunayGrid):
     7
     """
 
-    def __init__(self, base_num_rows=0, base_num_cols=0, dx=1.0,
-                 orientation='horizontal', shape='hex', reorient_links=True,
-                 **kwds):
+    def __init__(
+        self,
+        base_num_rows=0,
+        base_num_cols=0,
+        dx=1.0,
+        orientation="horizontal",
+        shape="hex",
+        reorient_links=True,
+        **kwds
+    ):
         """Create a grid of hexagonal cells.
 
         Create a regular 2D grid with hexagonal cells and triangular patches.
@@ -94,8 +100,9 @@ class HexModelGrid(VoronoiDelaunayGrid):
         """
         # Set number of nodes, and initialize if caller has given dimensions
         if base_num_rows * base_num_cols > 0:
-            self._initialize(base_num_rows, base_num_cols, dx, orientation,
-                             shape, reorient_links)
+            self._initialize(
+                base_num_rows, base_num_cols, dx, orientation, shape, reorient_links
+            )
         super(HexModelGrid, self).__init__(**kwds)
 
     @classmethod
@@ -103,13 +110,14 @@ class HexModelGrid(VoronoiDelaunayGrid):
         """
         LLCATS: GINF
         """
-        shape = params['shape']
-        spacing = params.get('spacing', 1.)
+        shape = params["shape"]
+        spacing = params.get("spacing", 1.)
 
         return cls(shape[0], shape[1], spacing)
 
-    def _initialize(self, base_num_rows, base_num_cols, dx, orientation,
-                    shape, reorient_links=True):
+    def _initialize(
+        self, base_num_rows, base_num_cols, dx, orientation, shape, reorient_links=True
+    ):
         r"""Set up a hexagonal grid.
 
         Sets up a hexagonal grid with cell spacing dx and
@@ -175,62 +183,76 @@ class HexModelGrid(VoronoiDelaunayGrid):
         'horizontal' grids, and only self._ncols for 'vertical' grids.
         """
         if self._DEBUG_TRACK_METHODS:
-            six.print_('HexModelGrid._initialize(' + str(base_num_rows) +
-                       ', ' + str(base_num_cols) + ', ' + str(dx) + ')')
+            six.print_(
+                "HexModelGrid._initialize("
+                + str(base_num_rows)
+                + ", "
+                + str(base_num_cols)
+                + ", "
+                + str(dx)
+                + ")"
+            )
 
         # Make sure the parameter *orientation* is correct
-        assert (orientation[0].lower() == 'h' or
-                orientation[0].lower() == 'v'), \
-            'orientation must be either "horizontal" (default) or "vertical"'
+        assert (
+            orientation[0].lower() == "h" or orientation[0].lower() == "v"
+        ), 'orientation must be either "horizontal" (default) or "vertical"'
 
         # Make sure the parameter *shape* is correct
-        assert (shape[0].lower() == 'h' or shape[0].lower() == 'r'), \
-            'shape must be either "hex" (default) or "rect"'
+        assert (
+            shape[0].lower() == "h" or shape[0].lower() == "r"
+        ), 'shape must be either "hex" (default) or "rect"'
 
         # Create a set of hexagonally arranged points. These will be our nodes.
-        if orientation[0].lower() == 'h' and shape[0].lower() == 'h':
+        if orientation[0].lower() == "h" and shape[0].lower() == "h":
             pts = HexModelGrid._hex_points_with_horizontal_hex(
-                base_num_rows, base_num_cols, dx)
-            self.orientation = 'horizontal'
+                base_num_rows, base_num_cols, dx
+            )
+            self.orientation = "horizontal"
             self._nrows = base_num_rows
-        elif orientation[0].lower() == 'h' and shape[0].lower() == 'r':
+        elif orientation[0].lower() == "h" and shape[0].lower() == "r":
             pts = HexModelGrid._hex_points_with_horizontal_rect(
-                base_num_rows, base_num_cols, dx)
-            self.orientation = 'horizontal'
+                base_num_rows, base_num_cols, dx
+            )
+            self.orientation = "horizontal"
             self._nrows = base_num_rows
             self._ncols = base_num_cols
             self._shape = (self._nrows, self._ncols)
-            self._nodes = numpy.arange(self._nrows * self._ncols,
-                                       dtype=int).reshape(self._shape)
-        elif orientation[0].lower() == 'v' and shape[0].lower() == 'h':
+            self._nodes = numpy.arange(self._nrows * self._ncols, dtype=int).reshape(
+                self._shape
+            )
+        elif orientation[0].lower() == "v" and shape[0].lower() == "h":
             pts = HexModelGrid._hex_points_with_vertical_hex(
-                base_num_rows, base_num_cols, dx)
-            self.orientation = 'vertical'
+                base_num_rows, base_num_cols, dx
+            )
+            self.orientation = "vertical"
             self._ncols = base_num_cols
         else:
             pts = HexModelGrid._hex_points_with_vertical_rect(
-                base_num_rows, base_num_cols, dx)
-            self.orientation = 'vertical'
+                base_num_rows, base_num_cols, dx
+            )
+            self.orientation = "vertical"
             self._nrows = base_num_rows
             self._ncols = base_num_cols
             self._shape = (self._nrows, self._ncols)
-            self._nodes = numpy.arange(self._nrows * self._ncols,
-                                       dtype=int).reshape(self._shape)
+            self._nodes = numpy.arange(self._nrows * self._ncols, dtype=int).reshape(
+                self._shape
+            )
             for col in range(self._ncols):
                 base_node = (col // 2) + (col % 2) * ((self._ncols + 1) // 2)
                 self._nodes[:, col] = numpy.arange(
-                    base_node, self._nrows * self._ncols, self._ncols)
+                    base_node, self._nrows * self._ncols, self._ncols
+                )
 
         # Call the VoronoiDelaunayGrid constructor to triangulate/Voronoi
         # the nodes into a grid.
-        super(HexModelGrid, self)._initialize(
-            pts[:, 0], pts[:, 1], reorient_links)
+        super(HexModelGrid, self)._initialize(pts[:, 0], pts[:, 1], reorient_links)
 
         # Handle special case of boundary nodes in rectangular grid shape.
         # One pair of edges will have the nodes staggered. By default, only the
         # outer nodes will be assigned boundary status; we need the inner edge
         # nodes on these "ragged" edges also to be flagged as boundary nodes.
-        if shape[0].lower() == 'r':
+        if shape[0].lower() == "r":
             self._set_boundary_stat_at_rect_grid_ragged_edges(orientation, dx)
 
         # Remember grid spacing
@@ -260,17 +282,15 @@ class HexModelGrid(VoronoiDelaunayGrid):
         >>> hg.status_at_node
         array([1, 1, 1, 1, 1, 0, 0, 1, 1, 1, 1, 1], dtype=uint8)
         """
-        if orientation[0].lower() == 'v':  # vert; top & bottom staggered
+        if orientation[0].lower() == "v":  # vert; top & bottom staggered
             bot_row = numpy.where(self.y_of_node <= 0.5 * dx)[0]
             self.status_at_node[bot_row] = self.status_at_node[0]
-            top_row = numpy.where(self.y_of_node
-                                  >= (self._nrows - 1) * dx)[0]
+            top_row = numpy.where(self.y_of_node >= (self._nrows - 1) * dx)[0]
             self.status_at_node[top_row] = self.status_at_node[0]
         else:  # horizontal orientation; left & right staggered
             left_row = numpy.where(self.x_of_node <= 0.5 * dx)[0]
             self.status_at_node[left_row] = self.status_at_node[0]
-            right_row = numpy.where(self.x_of_node
-                                    >= (self._ncols - 1) * dx)[0]
+            right_row = numpy.where(self.x_of_node >= (self._ncols - 1) * dx)[0]
             self.status_at_node[right_row] = self.status_at_node[0]
 
     def _create_cell_areas_array(self):
@@ -285,8 +305,9 @@ class HexModelGrid(VoronoiDelaunayGrid):
         .. math::
             A = 3 dx^2 / 2 \sqrt{3} \approx 0.866 dx^2
         """
-        self._area_of_cell = (0.8660254 * self._dx ** 2 +
-                              numpy.zeros(self.number_of_cells))
+        self._area_of_cell = 0.8660254 * self._dx ** 2 + numpy.zeros(
+            self.number_of_cells
+        )
         return self._area_of_cell
 
     @staticmethod
@@ -331,8 +352,9 @@ class HexModelGrid(VoronoiDelaunayGrid):
         if numpy.mod(num_rows, 2) == 0:  # even number of rows
             npts = num_rows * base_num_cols + (num_rows * num_rows) // 4
         else:  # odd number of rows
-            npts = num_rows * base_num_cols + \
-                ((num_rows - 1) // 2) * ((num_rows - 1) // 2)
+            npts = num_rows * base_num_cols + ((num_rows - 1) // 2) * (
+                (num_rows - 1) // 2
+            )
         pts = numpy.zeros((npts, 2))
         middle_row = num_rows // 2
         extra_cols = 0
@@ -347,7 +369,7 @@ class HexModelGrid(VoronoiDelaunayGrid):
                 extra_cols += 1
             else:
                 extra_cols -= 1
-            xshift = - half_dxh * extra_cols
+            xshift = -half_dxh * extra_cols
 
         return pts
 
@@ -443,8 +465,9 @@ class HexModelGrid(VoronoiDelaunayGrid):
         if numpy.mod(num_cols, 2) == 0:  # even number of columns
             npts = base_num_rows * num_cols + (num_cols * num_cols) // 4
         else:  # odd number of columns
-            npts = base_num_rows * num_cols + \
-                ((num_cols - 1) // 2) * ((num_cols - 1) // 2)
+            npts = base_num_rows * num_cols + ((num_cols - 1) // 2) * (
+                (num_cols - 1) // 2
+            )
         pts = numpy.zeros((npts, 2))
         middle_col = num_cols // 2
         extra_rows = 0
@@ -459,7 +482,7 @@ class HexModelGrid(VoronoiDelaunayGrid):
                 extra_rows += 1
             else:
                 extra_rows -= 1
-            yshift = - half_dxv * extra_rows
+            yshift = -half_dxv * extra_rows
 
         return pts
 
@@ -578,8 +601,7 @@ class HexModelGrid(VoronoiDelaunayGrid):
         try:
             return self._nodes[:, 0]
         except AttributeError:
-            raise AttributeError(
-                'Only rectangular Hex grids have defined edges.')
+            raise AttributeError("Only rectangular Hex grids have defined edges.")
 
     @property
     def nodes_at_right_edge(self):
@@ -598,8 +620,7 @@ class HexModelGrid(VoronoiDelaunayGrid):
         try:
             return self._nodes[:, -1]
         except AttributeError:
-            raise AttributeError(
-                'Only rectangular Hex grids have defined edges.')
+            raise AttributeError("Only rectangular Hex grids have defined edges.")
 
     @property
     def nodes_at_top_edge(self):
@@ -618,8 +639,7 @@ class HexModelGrid(VoronoiDelaunayGrid):
         try:
             return self._nodes[-1, :]
         except AttributeError:
-            raise AttributeError(
-                'Only rectangular Hex grids have defined edges.')
+            raise AttributeError("Only rectangular Hex grids have defined edges.")
 
     @property
     def nodes_at_bottom_edge(self):
@@ -638,12 +658,11 @@ class HexModelGrid(VoronoiDelaunayGrid):
         try:
             return self._nodes[0, :]
         except AttributeError:
-            raise AttributeError(
-                'Only rectangular Hex grids have defined edges.')
+            raise AttributeError("Only rectangular Hex grids have defined edges.")
 
     def node_row_and_column(self, node_id):
         """Row and column from node ID, FOR VERT RECT CONFIGURATION ONLY.
-        
+
         Examples
         --------
         >>> from landlab import HexModelGrid
@@ -654,19 +673,19 @@ class HexModelGrid(VoronoiDelaunayGrid):
         >>> grid.node_row_and_column(13)
         (2, 1)
         """
-        assert self.orientation[0] == 'v', 'grid orientation must be vertical'
+        assert self.orientation[0] == "v", "grid orientation must be vertical"
         try:
             (nr, nc) = self._shape
-        except:
+        except AttributeError:
             raise AttributeError(
-                'Only rectangular Hex grids have defined rows and columns.')
+                "Only rectangular Hex grids have defined rows and columns."
+            )
 
         row = node_id // nc
         n_mod_nc = node_id % nc
         half_nc = (nc + 1) // 2
         col = 2 * (n_mod_nc % half_nc) + n_mod_nc // half_nc
-        return (row, col)            
-            
+        return (row, col)
 
     def _configure_hexplot(self, data, data_label=None, color_map=None):
         """
@@ -711,18 +730,30 @@ class HexModelGrid(VoronoiDelaunayGrid):
         poly_verts = zeros((6, 2))
 
         # Figure out whether the orientation is horizontal or vertical
-        if self.orientation[0] == 'h':   # horizontal
-            offsets[:, 0] = array(
-                [0., apothem, apothem, 0., -apothem, -apothem])
+        if self.orientation[0] == "h":  # horizontal
+            offsets[:, 0] = array([0., apothem, apothem, 0., -apothem, -apothem])
             offsets[:, 1] = array(
-                [radius, radius / 2.0, -radius / 2.0, -radius, -radius / 2.0,
-                 radius / 2.0])
-        else:   # vertical
+                [
+                    radius,
+                    radius / 2.0,
+                    -radius / 2.0,
+                    -radius,
+                    -radius / 2.0,
+                    radius / 2.0,
+                ]
+            )
+        else:  # vertical
             offsets[:, 0] = array(
-                [radius / 2.0, radius, radius / 2.0, -radius / 2.0, -radius,
-                 -radius / 2.0])
-            offsets[:, 1] = array(
-                [apothem, 0., -apothem, -apothem, 0., apothem])
+                [
+                    radius / 2.0,
+                    radius,
+                    radius / 2.0,
+                    -radius / 2.0,
+                    -radius,
+                    -radius / 2.0,
+                ]
+            )
+            offsets[:, 1] = array([apothem, 0., -apothem, -apothem, 0., apothem])
 
         patches = []
         for i in range(self.number_of_nodes):
@@ -732,7 +763,8 @@ class HexModelGrid(VoronoiDelaunayGrid):
             patches.append(p)
 
         self._hexplot_pc = PatchCollection(
-            patches, cmap=color_map, edgecolor='none', linewidth=0.0)
+            patches, cmap=color_map, edgecolor="none", linewidth=0.0
+        )
 
         self._hexplot_configured = True
 
@@ -765,7 +797,7 @@ class HexModelGrid(VoronoiDelaunayGrid):
 
         try:
             self._hexplot_configured
-        except:
+        except AttributeError:
             self._configure_hexplot(data, data_label, color_map)
         else:
             if self._hexplot_pc.cmap != color_map:
@@ -800,7 +832,7 @@ class HexModelGrid(VoronoiDelaunayGrid):
         Returns
         -------
         boolean
-            ``True`` if node has a neighbor with a boundary ID, 
+            ``True`` if node has a neighbor with a boundary ID,
             ``False`` otherwise.
 
 
@@ -845,10 +877,9 @@ class HexModelGrid(VoronoiDelaunayGrid):
         else:
             return ans
 
-    def set_watershed_boundary_condition_outlet_id(self,
-                                                   outlet_id,
-                                                   node_data,
-                                                   nodata_value=-9999.):
+    def set_watershed_boundary_condition_outlet_id(
+        self, outlet_id, node_data, nodata_value=-9999.
+    ):
         """Set the boundary conditions for a watershed on a HexModelGrid.
 
         All nodes with nodata_value are set to CLOSED_BOUNDARY (4).
@@ -902,14 +933,15 @@ class HexModelGrid(VoronoiDelaunayGrid):
         LLCATS: BC
         """
         # make ring of no data nodes
-        self.status_at_node[self.boundary_nodes] =  CLOSED_BOUNDARY
+        self.status_at_node[self.boundary_nodes] = CLOSED_BOUNDARY
         # set no data nodes to inactive boundaries
         self.set_nodata_nodes_to_closed(node_data, nodata_value)
         # set the boundary condition (fixed value) at the outlet_node
         self.status_at_node[outlet_id] = FIXED_VALUE_BOUNDARY
 
-    def set_watershed_boundary_condition(self, node_data, nodata_value=-9999.,
-                                         return_outlet_id=False):
+    def set_watershed_boundary_condition(
+        self, node_data, nodata_value=-9999., return_outlet_id=False
+    ):
         """
         Finds the node adjacent to a boundary node with the smallest value.
         This node is set as the outlet.  The outlet node must have a data
@@ -968,16 +1000,16 @@ class HexModelGrid(VoronoiDelaunayGrid):
         LLCATS: BC
         """
         # make ring of no data nodes
-        self.status_at_node[self.boundary_nodes] =  CLOSED_BOUNDARY
+        self.status_at_node[self.boundary_nodes] = CLOSED_BOUNDARY
 
         # set no data nodes to inactive boundaries
         self.set_nodata_nodes_to_closed(node_data, nodata_value)
 
-        #locs is a list that contains locations where
-        #node data is not equal to the nodata value
+        # locs is a list that contains locations where
+        # node data is not equal to the nodata value
         locs = numpy.where(node_data != nodata_value)
         if len(locs) < 1:
-            raise ValueError('All data values are no_data values')
+            raise ValueError("All data values are no_data values")
 
         # now find minimum of the data values
         min_val = numpy.min(node_data[locs])
@@ -991,7 +1023,7 @@ class HexModelGrid(VoronoiDelaunayGrid):
             # now check the min locations to see if any are next to
             # a boundary node
             local_not_found = True
-            next_to_boundary=[]
+            next_to_boundary = []
 
             # check all nodes rather than selecting the first node that meets
             # the criteria
@@ -999,18 +1031,24 @@ class HexModelGrid(VoronoiDelaunayGrid):
                 next_to_boundary.append(self.node_has_boundary_neighbor(min_locs[i]))
 
             # if any of those nodes were adjacent to the boundary, check
-            #that  there is only one. If only one, set as outlet loc, else,
+            # that  there is only one. If only one, set as outlet loc, else,
             # raise a value error
             if any(next_to_boundary):
                 local_not_found = False
-                if sum(next_to_boundary)>1:
-                    potential_locs = min_locs[numpy.where(numpy.asarray(next_to_boundary))[0]]
-                    raise ValueError(('Grid has two potential outlet nodes.'
-                                      'They have the following node IDs: \n'+str(potential_locs)+
-                                     '\nUse the method set_watershed_boundary_condition_outlet_id '
-                                     'to explicitly select one of these '
-                                     'IDs as the outlet node.'
-                                     ))
+                if sum(next_to_boundary) > 1:
+                    potential_locs = min_locs[
+                        numpy.where(numpy.asarray(next_to_boundary))[0]
+                    ]
+                    raise ValueError(
+                        (
+                            "Grid has two potential outlet nodes."
+                            "They have the following node IDs: \n"
+                            + str(potential_locs)
+                            + "\nUse the method set_watershed_boundary_condition_outlet_id "
+                            "to explicitly select one of these "
+                            "IDs as the outlet node."
+                        )
+                    )
                 else:
                     outlet_loc = min_locs[numpy.where(next_to_boundary)[0][0]]
 
@@ -1021,8 +1059,7 @@ class HexModelGrid(VoronoiDelaunayGrid):
                 # first find the locations of all values greater
                 # than the old minimum
                 # not done with outer while
-                locs = numpy.where((node_data > min_val) &
-                                (node_data != nodata_value))
+                locs = numpy.where((node_data > min_val) & (node_data != nodata_value))
                 # now find new minimum of these values
                 min_val = numpy.min(node_data[locs])
                 min_locs = numpy.where(node_data == min_val)[0]
@@ -1037,6 +1074,7 @@ class HexModelGrid(VoronoiDelaunayGrid):
         if return_outlet_id:
             return as_id_array(numpy.array([outlet_loc]))
 
+
 def from_dict(param_dict):
     """
     Create a HexModelGrid from the dictionary-like object, *param_dict*.
@@ -1046,12 +1084,12 @@ def from_dict(param_dict):
     """
     # Read and create a basic HexModelGrid
     try:
-        n_rows = int(param_dict['NUM_ROWS'])
-        n_cols = int(param_dict['NUM_COLS'])
-        dx = float(param_dict.get('GRID_SPACING', 1.))
-    except KeyError as e:
+        n_rows = int(param_dict["NUM_ROWS"])
+        n_cols = int(param_dict["NUM_COLS"])
+        dx = float(param_dict.get("GRID_SPACING", 1.))
+    except KeyError:
         raise
-    except ValueError as e:
+    except ValueError:
         raise
     else:
         hg = HexModelGrid(n_rows, n_cols, dx)
