@@ -1,22 +1,22 @@
 import numpy as np
 
-from .status import StatusGrid
-from .links import link_is_active, find_active_links, LinkGrid
-from .links import _split_link_ends
-from .cells import CellGrid
-from .nodes import NodeGrid
 from landlab.utils.decorators import deprecated
 
+from .cells import CellGrid
+from .links import LinkGrid, _split_link_ends, find_active_links
+from .nodes import NodeGrid
+from .status import StatusGrid
+
 
 def _default_axis_names(n_dims):
     """Returns a tuple of the default axis names."""
-    _DEFAULT_NAMES = ('z', 'y', 'x')
-    return _DEFAULT_NAMES[- n_dims:]
+    _DEFAULT_NAMES = ("z", "y", "x")
+    return _DEFAULT_NAMES[-n_dims:]
 
 
 def _default_axis_units(n_dims):
     """Returns a tuple of the default axis units."""
-    return ('-', ) * n_dims
+    return ("-",) * n_dims
 
 
 class BaseGrid(object):
@@ -79,8 +79,15 @@ class BaseGrid(object):
     array([0, 2])
     """
 
-    def __init__(self, nodes, axis_name=None, axis_units=None,
-                 node_status=None, links=None, cells=None):
+    def __init__(
+        self,
+        nodes,
+        axis_name=None,
+        axis_units=None,
+        node_status=None,
+        links=None,
+        cells=None,
+    ):
         """__init__([coord0, coord1, ...], axis_name=None, axis_units=None)
 
         Parameters
@@ -162,13 +169,17 @@ class BaseGrid(object):
         if links is not None and node_status is not None:
             links = _split_link_ends(links)
             self._active_link_grid = BaseGrid.create_active_link_grid(
-                self.status_at_node, links, self.number_of_nodes)
+                self.status_at_node, links, self.number_of_nodes
+            )
 
     @staticmethod
     def create_active_link_grid(node_status, links, number_of_nodes):
         active_link_ids = find_active_links(node_status, links)
-        return LinkGrid((links[0][active_link_ids], links[1][active_link_ids]),
-                        number_of_nodes, link_ids=active_link_ids)
+        return LinkGrid(
+            (links[0][active_link_ids], links[1][active_link_ids]),
+            number_of_nodes,
+            link_ids=active_link_ids,
+        )
 
     @property
     def ndim(self):
@@ -292,8 +303,10 @@ class BaseGrid(object):
     def status_at_node(self, status):
         self._status_grid.node_status = status
         self._active_link_grid = BaseGrid.create_active_link_grid(
-            self.status_at_node, (self.node_at_link_start,
-                                  self.node_at_link_end), self.number_of_nodes)
+            self.status_at_node,
+            (self.node_at_link_start, self.node_at_link_end),
+            self.number_of_nodes,
+        )
 
     def active_nodes(self):
         return self._status_grid.active_nodes()
@@ -316,7 +329,7 @@ class BaseGrid(object):
     def active_links(self):
         return self._active_link_grid.link_id
 
-    @deprecated(use='length_of_link', version=1.0)
+    @deprecated(use="length_of_link", version=1.0)
     def link_length(self, link=None):
         return self.length_of_link(link=link)
 
@@ -346,8 +359,7 @@ class BaseGrid(object):
         if link is None:
             node0, node1 = (self.node_at_link_start, self.node_at_link_end)
         else:
-            node0, node1 = (self.node_at_link_start[link],
-                            self.node_at_link_end[link])
+            node0, node1 = (self.node_at_link_start[link], self.node_at_link_end[link])
 
         return self.node_to_node_distance(node0, node1)
 
@@ -376,12 +388,16 @@ class BaseGrid(object):
         array([ 0.,  3.,  4.,  5.])
         """
         return point_to_point_distance(
-            self._get_coord_at_node(node0), self._get_coord_at_node(node1),
-            out=out)
+            self._get_coord_at_node(node0), self._get_coord_at_node(node1), out=out
+        )
 
         node0, node1 = np.broadcast_arrays(node0, node1)
-        return np.sqrt(np.sum((self.coord_at_node[:, node1] -
-                               self.coord_at_node[:, node0]) ** 2, axis=0))
+        return np.sqrt(
+            np.sum(
+                (self.coord_at_node[:, node1] - self.coord_at_node[:, node0]) ** 2,
+                axis=0,
+            )
+        )
 
     def point_to_node_distance(self, point, node=None, out=None):
         """Distance from a point to a node.
@@ -412,8 +428,7 @@ class BaseGrid(object):
         >>> out
         array([ 0.,  3.,  4.,  5.])
         """
-        return point_to_point_distance(point, self._get_coord_at_node(node),
-                                       out=out)
+        return point_to_point_distance(point, self._get_coord_at_node(node), out=out)
 
     def point_to_node_angle(self, point, node=None, out=None):
         """Angle from a point to a node.
@@ -444,8 +459,7 @@ class BaseGrid(object):
         >>> out / np.pi
         array([ 0.  ,  0.  ,  0.5 ,  0.25])
         """
-        return point_to_point_angle(point, self._get_coord_at_node(node),
-                                    out=out)
+        return point_to_point_angle(point, self._get_coord_at_node(node), out=out)
 
     def point_to_node_azimuth(self, point, node=None, out=None):
         """Azimuth from a point to a node.
@@ -478,8 +492,7 @@ class BaseGrid(object):
         >>> out
         array([ 90.,  90.,   0.,  45.])
         """
-        return point_to_point_azimuth(point, self._get_coord_at_node(node),
-                                      out=out)
+        return point_to_point_azimuth(point, self._get_coord_at_node(node), out=out)
 
     def point_to_node_vector(self, point, node=None, out=None):
         """Azimuth from a point to a node.
@@ -516,8 +529,7 @@ class BaseGrid(object):
         array([[ 0.],
                [ 1.]])
         """
-        return point_to_point_vector(point, self._get_coord_at_node(node),
-                                     out=out)
+        return point_to_point_vector(point, self._get_coord_at_node(node), out=out)
 
     def _get_coord_at_node(self, node=None):
         if node is None:
